==> s2dverification_2.8.0.tar.gz: s2dverification/man/Eno.Rd <==
\name{Eno}
\alias{Eno}
\title{
Computes Effective Sample Size With Classical Method
}
\description{
Computes the effective number of independent values along the posdim dimension of a matrix.\cr
This effective number of independent observations can be used in statistical/inference tests.\cr
Based on eno function from Caio Coelho from rclim.txt.
}
\usage{
Eno(obs, posdim)
}
\arguments{
  \item{obs}{
Matrix of any number of dimensions up to 10.
  }
  \item{posdim}{
Dimension along which to compute the effective sample size.
  }
}
\value{
Same dimensions as var but without the posdim dimension.
}
\examples{
# See examples on Load() to understand the first lines in this example
  \dontrun{
configfile <- paste0(tempdir(), '/sample.conf')
ConfigFileCreate(configfile, confirm = FALSE)
c <- ConfigFileOpen(configfile)
c <- ConfigEditDefinition(c, 'DEFAULT_VAR_MIN', '-1e19', confirm = FALSE)
c <- ConfigEditDefinition(c, 'DEFAULT_VAR_MAX', '1e19', confirm = FALSE)
data_path <- system.file('sample_data', package = 's2dverification')
exp_data_path <- paste0(data_path, '/model/$EXP_NAME$/')
obs_data_path <- paste0(data_path, '/$OBS_NAME$/')
c <- ConfigAddEntry(c, 'experiments', dataset_name = 'experiment', 
     var_name = 'tos', main_path = exp_data_path,
     file_path = '$STORE_FREQ$_mean/$VAR_NAME$_3hourly/$VAR_NAME$_$START_DATE$.nc')
c <- ConfigAddEntry(c, 'observations', dataset_name = 'observation', 
     var_name = 'tos', main_path = obs_data_path,
     file_path = '$STORE_FREQ$_mean/$VAR_NAME$/$VAR_NAME$_$YEAR$$MONTH$.nc')
ConfigFileSave(c, configfile, confirm = FALSE)

# Now we are ready to use Load().
startDates <- c('19851101', '19901101', '19951101', '20001101', '20051101')
sampleData <- Load('tos', c('experiment'), c('observation'), startDates, 
                   output = 'lonlat', latmin = 27, latmax = 48, lonmin = -12,
                   lonmax = 40, configfile = configfile)
  }
  \dontshow{
startDates <- c('19851101', '19901101', '19951101', '20001101', '20051101')
sampleData <- s2dverification:::.LoadSampleData('tos', c('experiment'), 
                                                c('observation'), startDates,
                                                output = 'lonlat', 
                                                latmin = 27, latmax = 48, 
                                                lonmin = -12, lonmax = 40) 
  }
sampleData$mod <- Season(sampleData$mod, 4, 11, 1, 12)
eno <- Eno(sampleData$mod[1, 1, , 1, , ], 1)
PlotEquiMap(eno, sampleData$lon, sampleData$lat)
}
\author{
History:\cr
0.1  -  2011-05  (V. Guemas, \email{virginie.guemas at ic3.cat})  -  Original code\cr
1.0  -  2013-09  (N. Manubens, \email{nicolau.manubens at ic3.cat})  -  Formatting to R CRAN
}
\keyword{datagen}

==> s2dverification_2.8.5.tar.gz: s2dverification/man/Eno.Rd <==
\name{Eno}
\alias{Eno}
\title{
Computes Effective Sample Size With Classical Method
}
\description{
Computes the effective number of independent values along the posdim dimension of a matrix.\cr
This effective number of independent observations can be used in statistical/inference tests.\cr
Based on eno function from Caio Coelho from rclim.txt.
}
\usage{
Eno(obs, posdim)
}
\arguments{
  \item{obs}{
Matrix of any number of dimensions up to 10.
  }
  \item{posdim}{
Dimension along which to compute the effective sample size.
  }
}
\value{
Same dimensions as var but without the posdim dimension.
}
\examples{
# See examples on Load() to understand the first lines in this example
  \dontrun{
data_path <- system.file('sample_data', package = 's2dverification')
exp <- list(
         name = 'experiment',
         path = file.path(data_path, 'model/$EXP_NAME$/monthly_mean',
                          '$VAR_NAME$_3hourly/$VAR_NAME$_$START_DATES$.nc')
       )
obs <- list(
         name = 'observation',
         path = file.path(data_path, 'observation/$OBS_NAME$/monthly_mean',
                          '$VAR_NAME$/$VAR_NAME$_$YEAR$$MONTH$.nc')
       )
# Now we are ready to use Load().
startDates <- c('19851101', '19901101', '19951101', '20001101', '20051101')
sampleData <- Load('tos', list(exp), list(obs), startDates,
                   leadtimemin = 1, leadtimemax = 4, output = 'lonlat',
                   latmin = 27, latmax = 48, lonmin = -12, lonmax = 40)
  }
  \dontshow{
startDates <- c('19851101', '19901101', '19951101', '20001101', '20051101')
sampleData <- s2dverification:::.LoadSampleData('tos', c('experiment'), 
                                                c('observation'), startDates,
                                                output = 'lonlat', 
                                                latmin = 27, latmax = 48, 
                                                lonmin = -12, lonmax = 40) 
  }
sampleData$mod <- Season(sampleData$mod, 4, 11, 1, 12)
eno <- Eno(sampleData$mod[1, 1, , 1, , ], 1)
PlotEquiMap(eno, sampleData$lon, sampleData$lat)
}
\author{
History:\cr
0.1  -  2011-05  (V. Guemas, \email{virginie.guemas at ic3.cat})  -  Original code\cr
1.0  -  2013-09  (N. Manubens, \email{nicolau.manubens at ic3.cat})  -  Formatting to R CRAN
}
\keyword{datagen}
